import './App.css';
import { useState } from 'react';

const Spoiler = ({ header = "+", open, children }) => {
  const [openState, setOpenState] = useState(open ? true : false)

  return (
    <>
      {header}
      <button onClick={() => setOpenState(!openState)}> {openState ? "hide" : "show"}</button>
      {openState && children}
    </>
  )
}

const RangeInput = ({ min, max }) => {
  const [inputValue, setInputValue] = useState("")

  return (
    <input className={(inputValue.length < min || inputValue.length > max) ? "error" : "valid"} value={inputValue} onChange={e => setInputValue(e.target.value)} />
  )
}

const PasswordConfirm = ({ min }) => {
  const [input, setInput] = useState("")
  const [inputValidation, setInputValidation] = useState("")
  const validation = new RegExp(`^(?=.*[0-9]).{${min},}$`)

  return (
    <div className="pass-validation">
      <span>password must be at least {min} characters long and contain a number </span>
      <input type='password' value={input} onChange={e => setInput(e.target.value)} />
      <input type='password' value={inputValidation} onChange={e => setInputValidation(e.target.value)} />
      <button disabled={!(input === inputValidation && validation.test(input))}>VALID</button>
    </div>
  )
}

function App() {
  return (
    <div className="App">
      <Spoiler header={<h1>Заголовок</h1>} open>
        Контент 1
        <p>
          лорем ипсум траливали и тп.
        </p>
      </Spoiler>

      <Spoiler>
        <h2>Контент 2</h2>
        <p>
          лорем ипсум траливали и тп.
        </p>
      </Spoiler>

      <RangeInput min={2} max={10} />

      <PasswordConfirm min={2} />
    </div>
  );
}

export default App;